/************************************************************************/
/* astronomy.h - Global header for astronomy stuff.			*/
/************************************************************************/
/*
 *  (C)2000 Todd Shadburn
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/
/* History:								*/
/* (12-09-2000) Original creation date. Todd Shadburn			*/
/************************************************************************/

#ifndef _ASTRONOMY_H_
#define _ASTRONOMY_H_

#include <math.h>

#ifndef PI
#define PI		(3.14159265358979323846)
#endif

#define RADEG		(180.0/PI)
#define DEGRAD		(PI/180.0)
#define sind(x)		sin((x)*DEGRAD)
#define cosd(x)		cos((x)*DEGRAD)
#define tand(x)		tan((x)*DEGRAD)
#define asind(x)	(RADEG*asin(x))
#define acosd(x)	(RADEG*acos(x))
#define atand(x)	(RADEG*atan(x))
#define atan2d(y,x)	(RADEG*atan2((y), (x)))

typedef struct rectcoord_s
	{
	double x;		/* radians */
	double y;		/* radians */
	double z;		/* radians */
	} rectcoord_t;

typedef struct sphercoord_s
	{
	double ra;		/* decimal degrees */
	double dec;		/* decimal degrees */
	double r;
	} sphercoord_t;

double rev(double x);
double cbrt(double x);
double get_daynumber( int year, int month, int day, double ut);
double get_lst_degrees(double daynumber, double ut, double longitude);
double get_hour_angle(double lst, double ra);
double get_altitude_from_ra_and_dec(double latitude, double dec, double ha);
double get_azimuth_from_ra_and_dec(double latitude, double dec, double ha);
double get_degrees_from_hms(double hour, double minute, double sec);
int get_hms_from_degrees(double degrees, double *hour, double *minute, double *sec);
double get_hours_from_hms(double hour, double minute, double sec);
int get_dms_from_degrees(double degrees, double *deg, double *minute, double *second);
double normalize_hour(double hour);
double normalize_degree(double deg);
int coord_spherical_to_rectangular(sphercoord_t *sc, rectcoord_t *rc);
int coord_rectangular_to_spherical(rectcoord_t *rc, sphercoord_t *sc);
double get_current_lst(int timezonediff, double longitude);
double get_current_ut(int timezonediff);


/************************************************************************/
/*
 * Revamp on 2004-03-08
*/
/************************************************************************/

typedef struct _DateTime	DateTime;
struct _DateTime {
	int	year;
	int	month;
	int	day;
	int	hour;
	int	minute;
	int	second;
	int	dst;
};

double normalize (double value, double normal);
double current_ut_hours (int utcoffset);

/* The DateTime argument should be UTC */
double epoch_j2000_days (DateTime *dt);
double epoch_j2000_centuries (double epochdays);

int datetime_get_local_current (DateTime *dt);
int datetime_get_ut_current (DateTime *dt, int utcoffset);
double hours_from_datetime (DateTime *dt);
int days_in_month (int month, int year);

double GMST_degrees_from_datetime (DateTime *dt);
double LMST_degrees_from_datetime (DateTime *dt, double longitude);

double degrees_from_dms (int degrees, int arcminute, int arcsecond);

#endif

