/************************************************************************/
/* obscon.c - Observatory console utility source			*/
/************************************************************************/
/*
 *  (C)2004,2020 Todd Shadburn
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>
#include <math.h>



#define OUTPUT_FD		1 //stdout

#define	COMMAND_BUFFER_SIZE	1024


typedef struct commandbuf_s commandbuf_t;
struct commandbuf_s {
	int	len;
	char	buffer[COMMAND_BUFFER_SIZE];
};


void commandbuf_reset(commandbuf_t *c)
{
	if (c == NULL)
		return;
	c->len = 0;
	return;
}


int commandbuf_wait_line(commandbuf_t *cb)
{
	int	c = 0;

	commandbuf_reset(cb);

	while(1) {
		c = fgetc(stdin);
		if (c == EOF)
			return EOF;

		// handle special characters first
		switch(c) {
			case '\n':
				// terminal the string and return
				cb->buffer[cb->len] = 0;
				return 0;
				break;
		}

		// append the character to the command
		cb->buffer[cb->len] = (char)c;
		cb->len++;
		if (cb->len == COMMAND_BUFFER_SIZE) {
			// truncate and exit with error
			cb->buffer[cb->len-1] = 0; // truncate
			return 2;
		}
	}
	
	return 0;
}


int main (int argc, char **argv)
{
	int		rc;
	commandbuf_t	command;

	commandbuf_reset(&command);

	rc = console_initialize(OUTPUT_FD);

	while (1) {
		console_print_prompt();

		rc = commandbuf_wait_line(&command);
		if (rc != 0)
			break; // some error occurred

		// TODO fix this up correctly
		command.buffer[command.len] = 0;

		rc = console_handle_command(command.buffer);

	}

	return rc;
}


